%% DPSSEigenvalueGapsizeVsN_makefig.m 
% Code to generate figure for "The Fast Slepian Transform" Figure 1 Left panel
% Plots eigenvalue gapsize vs. N for a fixed W and a few values of epsilon
% Before running this script, run DPSSEigenvalueGapsizeVsN.m to generate 
% the data for Figure 1 Left panel
%
% Most recent change - 08/07/2017
%
% Copyright 2017, Santhosh Karnik
%
% This file is part of Fast Slepian Transform (FST) Toolbox version 1.0.
%
%    FST is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    FST is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with FST.  If not, see <http://www.gnu.org/licenses/>.
%
% If you use this code in an academic paper, please cite our paper:
% S. Karnik, Z. Zhu, M. B. Wakin, J. K. Romberg, and M. A. Davenport., 
% The fast Slepian transform, Appl. Comput. Harmon. Anal. (2017), 
% http://dx.doi.org/10.1016/j.acha.2017.07.005

% Load array of transition region eigenvalues
load('DPSS_Transition_Eigenvalues_N.mat')

% Compute the eigenvalue gapsize for each value of epsilon and N
vecEpsilon = logspace(-3,-12,4);
gapsize = zeros(length(vecN),length(vecEpsilon));
for ii = 1:length(vecEpsilon),
    gapsize(:,ii) = sum(V > vecEpsilon(ii) & V < 1-vecEpsilon(ii))';
end

% Compute the asymptotic bound on the eigenvalue gapsize
asybound = (2/pi^2)*log(vecN)'*log(1./vecEpsilon-1);

% For each value of epsilon, plot the eigenvalue gapsize vs. N and the 
% asymptotic bound vs. N.
% Most of the code below is for formatting
ColorRGBvals = [     0,         0,    1.0000;
                     0,    0.5000,         0;
                1.0000,         0,         0;
                     0,    0.7500,    0.7500;
                0.7500,         0,    0.7500;
                0.7500,    0.7500,         0;
                0.2500,    0.2500,    0.2500];
figure('Position', [50, 50, 800, 600]);
co = get(gca,'ColorOrder');
set(gca,'ColorOrder',ColorRGBvals([1:length(vecEpsilon),1:length(vecEpsilon)],:),'NextPlot','replacechildren');
semilogx(vecN(~flag),gapsize(~flag,:),'-',vecN,asybound,'--')
set(gca,'xscale','log')

axis([16,max(vecN),0,5*ceil(max(gapsize(:,end))/5)])
set(gca,'Xtick',2.^(4:16));
set(gca,'XTickLabel',{'2^4','2^5','2^6','2^7','2^8','2^9','2^{10}','2^{11}','2^{12}','2^{13}','2^{14}','2^{15}','2^{16}'})
set(gca,'XMinorTick','off')
set(gca,'Ytick',0:5:(5*ceil(max(gapsize(:,end))/5)));
set(gca,'fontsize',18)

xlabel('$N$','fontsize',22,'interpreter','latex')
ylabel('$\#\{\ell : \epsilon < \lambda_{N,W}^{(\ell)} < 1-\epsilon\}$','fontsize',22,'interpreter','latex')
title('Eigenvalue Gapsize vs. DPSS Length for $W = \frac{1}{4}$','fontsize',22,'interpreter','latex')

text(2^14,asybound(2^14,1)-1,'$\epsilon = 10^{-3}$','fontsize',18,'interpreter','latex')
text(2^14,asybound(2^14,2)-1,'$\epsilon = 10^{-6}$','fontsize',18,'interpreter','latex')
text(2^14,asybound(2^14,3)-1,'$\epsilon = 10^{-9}$','fontsize',18,'interpreter','latex')
text(2^14,asybound(2^14,4)-1,'$\epsilon = 10^{-12}$','fontsize',18,'interpreter','latex')

set(gca, 'LooseInset', [0,0,0,0]);