%% FastFourierExtension_makefig56.m 
% This code generates "The Fast Slepian Transform" Figures 5 and 6. 
% Before running this script, run FastFourierExtension.m to generate the 
% data for Figures 5 and 6. 
%
% Most recent change - 08/07/2017
%
% Copyright 2017, Santhosh Karnik
%
% This file is part of Fast Slepian Transform (FST) Toolbox version 1.0.
%
%    FST is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    FST is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with FST.  If not, see <http://www.gnu.org/licenses/>.
%
% If you use this code in an academic paper, please cite our paper:
% S. Karnik, Z. Zhu, M. B. Wakin, J. K. Romberg, and M. A. Davenport., 
% The fast Slepian transform, Appl. Comput. Harmon. Anal. (2017), 
% http://dx.doi.org/10.1016/j.acha.2017.07.005

% Load data
load('FastFourierExtension.mat')

Mmax = 2560;
index = (vecM <= Mmax);

% Plot RMS Error vs Number of terms for Fourier series, extended Fourier
% Series, and the fast extended Fourier series (using truncated pseudoinverse)
figure('Position', [50, 50, 800, 600]);
semilogy(vecM(index),Error_Fourier(index),'b-','linewidth',2)
hold on
semilogy(vecM(index),Error_FourierExtensionPinv(index),'g-','linewidth',3)
semilogy(vecM(index),Error_FourierExtensionPinvFast(index),'r--','linewidth',2)
axis([0,Mmax,1e-4,1])
h1 = legend('Fourier sum','Fourier extension (exact pinv)','Fourier extension (fast pinv)');
set(h1,'fontsize',18,'Location','northeast','interpreter','latex')
set(gca,'FontSize',18)
set(gca,'YTick',logspace(-4,0,5));
title('Relative RMS Error vs. Number of Terms','fontsize',22,'interpreter','latex')
xlabel('$M$','fontsize',22,'interpreter','latex')
ylabel('relative RMS error','fontsize',22,'interpreter','latex')
set(gca, 'LooseInset', [0,0,0,0]);

% Plot Average Time vs Number of terms for Fourier series, extended Fourier
% Series, and the fast extended Fourier series (using truncated pseudoinverse)
figure('Position', [50, 50, 800, 600]);
semilogy(vecM(index),mean(Time_Fourier(:,index),1),'b-','linewidth',2)
hold on
semilogy(vecM(index),mean(Time_FourierExtensionPinv(:,index),1),'g-','linewidth',3)
semilogy(vecM(index),mean(Time_FourierExtensionPinvFast(:,index),1),'r--','linewidth',2) 
axis([0,Mmax,8e-5,12.5])
h1 = legend('Fourier sum','Fourier extension (exact pinv)','Fourier extension (fast pinv)');
set(h1,'fontsize',18,'Location','southeast','interpreter','latex')
set(gca,'FontSize',18)
set(gca,'YTick',logspace(-4,1,6));
title('Average Computation Time vs. Number of Terms','fontsize',22,'interpreter','latex')
xlabel('$M$','fontsize',22,'interpreter','latex')
ylabel('average time (sec)','fontsize',22,'interpreter','latex')
set(gca, 'LooseInset', [0,0,0,0]);

% Plot RMS Error vs Number of terms for Fourier series, extended Fourier
% Series, and the fast extended Fourier series (using Tikhonov regularization)
figure('Position', [50, 50, 800, 600]);
semilogy(vecM(index),Error_Fourier(index),'b-','linewidth',2)
hold on
semilogy(vecM(index),Error_FourierExtensionTik(index),'g-','linewidth',3)
semilogy(vecM(index),Error_FourierExtensionTikFast(index),'r--','linewidth',2)
axis([0,Mmax,1e-4,1])
h1 = legend('Fourier sum','Fourier extension (exact Tikhonov)','Fourier extension (fast Tikhonov)');
set(h1,'fontsize',18,'Location','northeast','interpreter','latex')
set(gca,'FontSize',18)
set(gca,'YTick',logspace(-4,0,5));
title('Relative RMS Error vs. Number of Terms','fontsize',22,'interpreter','latex')
xlabel('$M$','fontsize',22,'interpreter','latex')
ylabel('relative RMS error','fontsize',22,'interpreter','latex')
set(gca, 'LooseInset', [0,0,0,0]);

% Plot Average Time vs Number of terms for Fourier series, extended Fourier
% Series, and the fast extended Fourier series (using Tikhonov regularization)
figure('Position', [50, 50, 800, 600]);
semilogy(vecM(index),mean(Time_Fourier(:,index),1),'b-','linewidth',2)
hold on
semilogy(vecM(index),mean(Time_FourierExtensionTik(:,index),1),'g-','linewidth',3)
semilogy(vecM(index),mean(Time_FourierExtensionTikFast(:,index),1),'r--','linewidth',2) 
axis([0,Mmax,8e-5,12.5])
h1 = legend('Fourier sum','Fourier extension (exact Tikhonov)','Fourier extension (fast Tikhonov)');
set(h1,'fontsize',18,'Location','southeast','interpreter','latex')
set(gca,'FontSize',18)
set(gca,'YTick',logspace(-4,1,6));
title('Average Computation Time vs. Number of Terms','fontsize',22,'interpreter','latex')
xlabel('$M$','fontsize',22,'interpreter','latex')
ylabel('average time (sec)','fontsize',22,'interpreter','latex')
set(gca, 'LooseInset', [0,0,0,0]);